==> org.eclipse.passage.lic.jface.source_0.6.100.v20200223-1541.jar: org/eclipse/passage/lic/jface/dialogs/LicensingStatusDialog.java <==
/*******************************************************************************
 * Copyright (c) 2018, 2020 ArSysOp
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * https://www.eclipse.org/legal/epl-2.0/.
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     ArSysOp - initial API and implementation
 *******************************************************************************/
package org.eclipse.passage.lic.jface.dialogs;

import java.util.Collections;
import java.util.Optional;

import org.eclipse.core.runtime.preferences.IEclipsePreferences;
import org.eclipse.core.runtime.preferences.IEclipsePreferences.IPreferenceChangeListener;
import org.eclipse.core.runtime.preferences.IEclipsePreferences.PreferenceChangeEvent;
import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.dialogs.TitleAreaDialog;
import org.eclipse.jface.resource.JFaceResources;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.jface.window.Window;
import org.eclipse.passage.lic.api.LicensingConfiguration;
import org.eclipse.passage.lic.api.access.AccessManager;
import org.eclipse.passage.lic.api.inspector.FeatureCase;
import org.eclipse.passage.lic.api.inspector.FeatureInspector;
import org.eclipse.passage.lic.api.inspector.HardwareInspector;
import org.eclipse.passage.lic.api.restrictions.RestrictionVerdict;
import org.eclipse.passage.lic.base.restrictions.RestrictionVerdicts;
import org.eclipse.passage.lic.equinox.ApplicationConfigurations;
import org.eclipse.passage.lic.equinox.LicensingEquinox;
import org.eclipse.passage.lic.internal.jface.i18n.JFaceMessages;
import org.eclipse.passage.lic.internal.jface.viewers.LicensingRequirementViewer;
import org.eclipse.passage.lic.jface.resource.LicensingColors;
import org.eclipse.passage.lic.jface.resource.LicensingImages;
import org.eclipse.passage.lic.jface.viewers.RestrictionRepresenters;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Table;

public class LicensingStatusDialog extends TitleAreaDialog implements IPreferenceChangeListener {

	public static final int HARDWARE_INSPECTOR_ID = IDialogConstants.CLIENT_ID + 1;

	public static final int IMPORT_LICENSE_ID = IDialogConstants.CLIENT_ID + 2;

	public static final int SHOW_CONFIGURATION_ID = IDialogConstants.CLIENT_ID + 3;

	private final AccessManager accessManager;
	private final HardwareInspector hardwareInspector;
	private final FeatureInspector featureInspector;
	private final String[] features;

	private FeatureCase featureCase;

	private TableViewer tableViewer;
	IEclipsePreferences preferences = LicensingColors.getPreferences();

	private Iterable<RestrictionVerdict> restrictions = Collections.emptyList();

	public LicensingStatusDialog(Shell shell, String... features) {
		super(shell);
		accessManager = LicensingEquinox.getAccessManager();
		featureInspector = LicensingEquinox.getFeatureInspector();
		hardwareInspector = LicensingEquinox.getHardwareInspector();
		this.features = new String[features.length];
		System.arraycopy(features, 0, this.features, 0, features.length);
	}

	@Override
	protected void configureShell(Shell newShell) {
		super.configureShell(newShell);
		newShell.setText(JFaceMessages.LicensingStatusDialog_shell);
		newShell.setImage(getDefaultImage());
	}

	@Override
	protected Control createDialogArea(Composite parent) {
		setTitle(JFaceMessages.LicensingStatusDialog_title);
		Composite area = (Composite) super.createDialogArea(parent);
		createAreaContent(area);
		Dialog.applyDialogFont(area);
		return area;
	}

	protected void computeStatus() {
		restrictions = featureCase.getRestrictions();
		RestrictionVerdict last = RestrictionVerdicts.resolveLastVerdict(restrictions);
		if (last == null) {
			setErrorMessage(null);
			setMessage(RestrictionRepresenters.resolveSummary(last));
		} else {
			setErrorMessage(RestrictionRepresenters.resolveSummary(last));
		}
		getContents().getDisplay().asyncExec(() -> updateTable());
	}

	protected void createAreaContent(Composite area) {
		Composite contents = new Composite(area, SWT.NONE);
		contents.setLayout(new GridLayout(1, false));
		contents.setLayoutData(new GridData(GridData.FILL_BOTH));
		Table tableDetails = new Table(contents, SWT.BORDER);
		tableDetails.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
		tableViewer = LicensingRequirementViewer.createTableViewer(tableDetails);
		setMessage(JFaceMessages.LicensingStatusDialog_ok_initilaizing);
		area.getDisplay().asyncExec(() -> initializeFeatureCase());
		Group contactsGroup = new Group(area, SWT.NONE);
		contactsGroup.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, false));
		contactsGroup.setText(JFaceMessages.LicensingStatusDialog_contact_group);
		contactsGroup.setFont(JFaceResources.getDialogFont());
		contactsGroup.setLayout(new GridLayout());
		StyledText contactsText = new StyledText(contactsGroup, SWT.READ_ONLY | SWT.MULTI);
		contactsText.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, false));
		contactsText.setText(ApplicationConfigurations.getLicensingContacts());
		contactsText.setFont(JFaceResources.getDialogFont());

		if (preferences != null) {
			preferences.addPreferenceChangeListener(this);
		}
	}

	protected void initializeFeatureCase() {
		featureCase = featureInspector.inspectFeatures(features);
		tableViewer.setInput(featureCase.getRequirements());
		computeStatus();
	}

	@Override
	protected void createButtonsForButtonBar(Composite parent) {
		((GridLayout) parent.getLayout()).makeColumnsEqualWidth = false;
		Button detailsButton = createButton(parent, SHOW_CONFIGURATION_ID,
				JFaceMessages.LicensingStatusDialog_configuration_button, false);
		detailsButton.setImage(LicensingImages.getImage(LicensingImages.IMG_DEFAULT));
		detailsButton.setEnabled(accessManager != null);
		Button importButton = createButton(parent, IMPORT_LICENSE_ID, JFaceMessages.LicensingStatusDialog_import_button,
				false);
		importButton.setImage(LicensingImages.getImage(LicensingImages.IMG_IMPORT));
		importButton.setEnabled(accessManager != null);
		Button inspector = createButton(parent, HARDWARE_INSPECTOR_ID,
				JFaceMessages.LicensingStatusDialog_hardware_button, false);
		inspector.setImage(LicensingImages.getImage(LicensingImages.IMG_INSPECTOR));
		inspector.setEnabled(hardwareInspector != null);
		createButton(parent, IDialogConstants.CLOSE_ID, IDialogConstants.CLOSE_LABEL, true);
	}

	@Override
	protected void setButtonLayoutData(Button button) {
		GridData data = new GridData(GridData.HORIZONTAL_ALIGN_FILL);
		int length = button.getText().length();
		int widthHint = convertWidthInCharsToPixels(length + 8);
		Point minSize = button.computeSize(SWT.DEFAULT, SWT.DEFAULT, true);
		data.widthHint = Math.max(widthHint, minSize.x);
		button.setLayoutData(data);
	}

	@Override
	protected void buttonPressed(int buttonId) {
		switch (buttonId) {
		case SHOW_CONFIGURATION_ID:
			showConfigurationPressed();
			break;
		case IMPORT_LICENSE_ID:
			importLicensePressed();
			break;
		case HARDWARE_INSPECTOR_ID:
			hardwareInspectorPressed();
			break;
		default:
			okPressed();
			break;
		}
	}

	protected void showConfigurationPressed() {
		LicensingConfigurationDialog dialog = new LicensingConfigurationDialog(getShell());
		dialog.open();
	}

	protected void importLicensePressed() {
		LicensingConfiguration configuration = ApplicationConfigurations.getLicensingConfiguration();
		ImportLicenseDialog dialog = new ImportLicenseDialog(getShell(), configuration);
		if (Window.OK == dialog.open()) {
			computeStatus();
		}
	}

	protected void hardwareInspectorPressed() {
		HardwareInspectorDialog dialog = new HardwareInspectorDialog(getShell(), hardwareInspector);
		dialog.open();
	}

	@Override
	protected boolean isResizable() {
		return true;
	}

	@Override
	public void preferenceChange(PreferenceChangeEvent event) {
		updateTable();
	}

	protected void updateTable() {
		if (tableViewer != null && tableViewer.getTable() != null && !tableViewer.getTable().isDisposed()) {
			tableViewer.refresh();
		}
	}

	@Override
	public boolean close() {
		Optional.ofNullable(preferences).ifPresent(p -> p.removePreferenceChangeListener(LicensingStatusDialog.this));
		Optional.ofNullable(featureCase).ifPresent(fc -> fc.close());
		return super.close();
	}

	public Iterable<RestrictionVerdict> getRestrictions() {
		return restrictions;
	}
}

==> org.eclipse.passage.lic.jface.source_0.6.200.v20200602-1615.jar: org/eclipse/passage/lic/jface/dialogs/LicensingStatusDialog.java <==
/*******************************************************************************
 * Copyright (c) 2018, 2020 ArSysOp
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * https://www.eclipse.org/legal/epl-2.0/.
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     ArSysOp - initial API and implementation
 *******************************************************************************/
package org.eclipse.passage.lic.jface.dialogs;

import java.util.Optional;

import org.eclipse.core.runtime.preferences.IEclipsePreferences;
import org.eclipse.core.runtime.preferences.IEclipsePreferences.IPreferenceChangeListener;
import org.eclipse.core.runtime.preferences.IEclipsePreferences.PreferenceChangeEvent;
import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.dialogs.TitleAreaDialog;
import org.eclipse.jface.resource.JFaceResources;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.jface.window.Window;
import org.eclipse.passage.lic.api.LicensingConfiguration;
import org.eclipse.passage.lic.api.access.AccessManager;
import org.eclipse.passage.lic.api.inspector.FeatureInspector;
import org.eclipse.passage.lic.api.inspector.HardwareInspector;
import org.eclipse.passage.lic.api.restrictions.RestrictionVerdict;
import org.eclipse.passage.lic.base.restrictions.RestrictionVerdicts;
import org.eclipse.passage.lic.equinox.ApplicationConfigurations;
import org.eclipse.passage.lic.equinox.LicensingEquinox;
import org.eclipse.passage.lic.internal.equinox.inspector.EquinoxFeatureCase;
import org.eclipse.passage.lic.internal.jface.i18n.JFaceMessages;
import org.eclipse.passage.lic.internal.jface.viewers.RestrictionVerdictViewer;
import org.eclipse.passage.lic.jface.resource.LicensingColors;
import org.eclipse.passage.lic.jface.resource.LicensingImages;
import org.eclipse.passage.lic.jface.viewers.RestrictionRepresenters;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Table;

public class LicensingStatusDialog extends TitleAreaDialog implements IPreferenceChangeListener {

	public static final int HARDWARE_INSPECTOR_ID = IDialogConstants.CLIENT_ID + 1;

	public static final int IMPORT_LICENSE_ID = IDialogConstants.CLIENT_ID + 2;

	public static final int SHOW_CONFIGURATION_ID = IDialogConstants.CLIENT_ID + 3;

	private final AccessManager accessManager;
	private final HardwareInspector hardwareInspector;
	private final FeatureInspector featureInspector;
	private final String[] features;

	private EquinoxFeatureCase featureCase;

	private TableViewer tableViewer;
	IEclipsePreferences preferences = LicensingColors.getPreferences();

	public LicensingStatusDialog(Shell shell, String... features) {
		super(shell);
		accessManager = LicensingEquinox.getAccessManager();
		featureInspector = LicensingEquinox.getFeatureInspector();
		hardwareInspector = LicensingEquinox.getHardwareInspector();
		this.features = new String[features.length];
		System.arraycopy(features, 0, this.features, 0, features.length);
	}

	@Override
	protected void configureShell(Shell newShell) {
		super.configureShell(newShell);
		newShell.setText(JFaceMessages.LicensingStatusDialog_shell);
		newShell.setImage(getDefaultImage());
	}

	@Override
	protected Control createDialogArea(Composite parent) {
		setTitle(JFaceMessages.LicensingStatusDialog_title);
		Composite area = (Composite) super.createDialogArea(parent);
		createAreaContent(area);
		Dialog.applyDialogFont(area);
		return area;
	}

	protected void computeStatus() {
		featureCase.reset();
		Iterable<RestrictionVerdict> restrictions = featureCase.getRestrictions();
		tableViewer.setInput(featureCase.status());
		RestrictionVerdict last = RestrictionVerdicts.resolveLastVerdict(restrictions);
		if (last == null) {
			setErrorMessage(null);
			setMessage(RestrictionRepresenters.resolveSummary(last));
		} else {
			setErrorMessage(RestrictionRepresenters.resolveSummary(last));
		}
		getContents().getDisplay().asyncExec(() -> updateTable());
	}

	protected void createAreaContent(Composite area) {
		Composite contents = new Composite(area, SWT.NONE);
		contents.setLayout(new GridLayout(1, false));
		contents.setLayoutData(new GridData(GridData.FILL_BOTH));
		Table tableDetails = new Table(contents, SWT.BORDER);
		tableDetails.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
		tableViewer = RestrictionVerdictViewer.createTableViewer(tableDetails);
		setMessage(JFaceMessages.LicensingStatusDialog_ok_initilaizing);
		area.getDisplay().asyncExec(() -> initializeFeatureCase());
		Group contactsGroup = new Group(area, SWT.NONE);
		contactsGroup.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, false));
		contactsGroup.setText(JFaceMessages.LicensingStatusDialog_contact_group);
		contactsGroup.setFont(JFaceResources.getDialogFont());
		contactsGroup.setLayout(new GridLayout());
		StyledText contactsText = new StyledText(contactsGroup, SWT.READ_ONLY | SWT.MULTI);
		contactsText.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, false));
		contactsText.setText(ApplicationConfigurations.getLicensingContacts());
		contactsText.setFont(JFaceResources.getDialogFont());

		if (preferences != null) {
			preferences.addPreferenceChangeListener(this);
		}
	}

	protected void initializeFeatureCase() {
		featureCase = (EquinoxFeatureCase) featureInspector.inspectFeatures(features);
		computeStatus();
	}

	@Override
	protected void createButtonsForButtonBar(Composite parent) {
		((GridLayout) parent.getLayout()).makeColumnsEqualWidth = false;
		Button detailsButton = createButton(parent, SHOW_CONFIGURATION_ID,
				JFaceMessages.LicensingStatusDialog_configuration_button, false);
		detailsButton.setImage(LicensingImages.getImage(LicensingImages.IMG_DEFAULT));
		detailsButton.setEnabled(accessManager != null);
		Button importButton = createButton(parent, IMPORT_LICENSE_ID, JFaceMessages.LicensingStatusDialog_import_button,
				false);
		importButton.setImage(LicensingImages.getImage(LicensingImages.IMG_IMPORT));
		importButton.setEnabled(accessManager != null);
		Button inspector = createButton(parent, HARDWARE_INSPECTOR_ID,
				JFaceMessages.LicensingStatusDialog_hardware_button, false);
		inspector.setImage(LicensingImages.getImage(LicensingImages.IMG_INSPECTOR));
		inspector.setEnabled(hardwareInspector != null);
		createButton(parent, IDialogConstants.CLOSE_ID, IDialogConstants.CLOSE_LABEL, true);
	}

	@Override
	protected void setButtonLayoutData(Button button) {
		GridData data = new GridData(GridData.HORIZONTAL_ALIGN_FILL);
		int length = button.getText().length();
		int widthHint = convertWidthInCharsToPixels(length + 8);
		Point minSize = button.computeSize(SWT.DEFAULT, SWT.DEFAULT, true);
		data.widthHint = Math.max(widthHint, minSize.x);
		button.setLayoutData(data);
	}

	@Override
	protected void buttonPressed(int buttonId) {
		switch (buttonId) {
		case SHOW_CONFIGURATION_ID:
			showConfigurationPressed();
			break;
		case IMPORT_LICENSE_ID:
			importLicensePressed();
			break;
		case HARDWARE_INSPECTOR_ID:
			hardwareInspectorPressed();
			break;
		default:
			okPressed();
			break;
		}
	}

	protected void showConfigurationPressed() {
		LicensingConfigurationDialog dialog = new LicensingConfigurationDialog(getShell());
		dialog.open();
	}

	protected void importLicensePressed() {
		LicensingConfiguration configuration = ApplicationConfigurations.getLicensingConfiguration();
		ImportLicenseDialog dialog = new ImportLicenseDialog(getShell(), configuration);
		if (Window.OK == dialog.open()) {
			computeStatus();
		}
	}

	protected void hardwareInspectorPressed() {
		HardwareInspectorDialog dialog = new HardwareInspectorDialog(getShell(), hardwareInspector);
		dialog.open();
	}

	@Override
	protected boolean isResizable() {
		return true;
	}

	@Override
	public void preferenceChange(PreferenceChangeEvent event) {
		featureCase.reset();
		updateTable();
	}

	protected void updateTable() {
		if (tableViewer != null && tableViewer.getTable() != null && !tableViewer.getTable().isDisposed()) {
			tableViewer.refresh();
		}
	}

	@Override
	public boolean close() {
		Optional.ofNullable(preferences).ifPresent(p -> p.removePreferenceChangeListener(LicensingStatusDialog.this));
		Optional.ofNullable(featureCase).ifPresent(fc -> fc.close());
		return super.close();
	}

	public Iterable<RestrictionVerdict> getRestrictions() {
		return featureCase.getRestrictions();
	}
}
